package net.sf.corn.exception;

/**
 * Exception listener is designed to listen exception caught or thrown events those triggered by  either {@link ExceptionCatcher} or {@link ExceptionBuilder}. 
*  Listeners are responsible for telling which Exceptions
 * are their subject and defining the action as {@link Runnable} implementation that need to be executed.
 * Action thread executions are controlled by {@link ExceptionEventBus} class.  
 * @author Serhat Dirik
 * @see ExceptionEventsBus
 * @see ExceptionBuilder
 */
public interface ExceptionListener {
	/**
	 * Tells if this listener interested in the given exception class
	 * @param exceptionClass the exception class to be checked
	 * @param thrown if true exception is thrown otherwise its get caught
	 * @return true if it's interested 
	 */
	public boolean isSubject(Class<? extends Exception> exceptionClass, boolean thrown);
	/**
	 * Gives the Runnable that it desired to be executed when the exception related events occurs
	 * @param exception the event source exception
 	 * @param thrown if true exception is thrown otherwise its get caught
	 * @return this is the action that need to be executed by exception bus 
	 */
	public Runnable action(final Exception exception,final  boolean thrown);
}
